errors/exceptions library

Exceptions / Errors

CacheException
Exception thrown when an illegal operation occurs during a caching request.
ParseException
Exception thrown when an illegal operation occurs during data parsing.