types/form_field library
Classes
-
FormField<
T> - When providing data to a form and then passing it forward, for instance, in a request body, one problem that is common here is the need of dealing with the cases where the field is not filled, and then one might need to treat every possible resulting Map (json) separately, either passing the not filled field with no value or not passing it at all.
Extensions
-
FormFieldPatterns
on FormField<
T> - Adds pattern-matching-related methods to FormField.