CacheException class
Exception thrown when an illegal operation occurs during a caching request.
For error-type counterparts, see CacheError.
- Implemented types
Constructors
- CacheException(String exception)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited